==> odoo_19.2a1.20260113.zip: odoo-19.2a1.post20260113/odoo/addons/base/tests/test_res_partner_bank.py <==
# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

# Copyright (c) 2015 ACSONE SA/NV (<http://acsone.eu>)

from odoo.tests import tagged

from odoo.addons.base.tests.common import SavepointCaseWithUserDemo


@tagged('at_install', '-post_install')  # LEGACY at_install
class TestResPartnerBank(SavepointCaseWithUserDemo):
    """Tests account_number
    """

    def test_sanitized_account_number(self):
        partner_bank_model = self.env['res.partner.bank']
        account_number = " BE-001 2518823 03 "
        vals = partner_bank_model.search([('account_number', '=', account_number)])
        self.assertEqual(0, len(vals))
        partner_bank = partner_bank_model.create({
            'account_number': account_number,
            'partner_id': self.env['res.partner'].create({'name': 'Pepper Test'}).id,
        })
        vals = partner_bank_model.search([('account_number', '=', account_number)])
        self.assertEqual(1, len(vals))
        self.assertEqual(partner_bank, vals[0])
        vals = partner_bank_model.search([('account_number', 'in', [account_number])])
        self.assertEqual(1, len(vals))
        self.assertEqual(partner_bank, vals[0])

        self.assertEqual(partner_bank.account_number, account_number)

        # sanitaze the account_number
        sanitized_account_number = 'BE001251882303'
        self.assertEqual(partner_bank.sanitized_account_number, sanitized_account_number)
        vals = partner_bank_model.search(
            [('account_number', '=', sanitized_account_number)])
        self.assertEqual(1, len(vals))
        self.assertEqual(partner_bank, vals[0])
        vals = partner_bank_model.search(
            [('account_number', 'in', [sanitized_account_number])])
        self.assertEqual(1, len(vals))
        self.assertEqual(partner_bank, vals[0])
        self.assertEqual(partner_bank.sanitized_account_number,
                         sanitized_account_number)

        # search is case insensitive
        vals = partner_bank_model.search(
            [('account_number', '=', sanitized_account_number.lower())])
        self.assertEqual(1, len(vals))
        vals = partner_bank_model.search(
            [('account_number', '=', account_number.lower())])
        self.assertEqual(1, len(vals))

        # updating the sanitized value will also update the account_number
        partner_bank.write({'sanitized_account_number': 'BE001251882303WRONG'})
        self.assertEqual(partner_bank.account_number, partner_bank.sanitized_account_number)

==> odoo_19.3a1.20260226.zip: odoo-19.3a1.post20260226/odoo/addons/base/tests/test_res_partner_bank.py <==
# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

# Copyright (c) 2015 ACSONE SA/NV (<http://acsone.eu>)

from odoo.tests import tagged, TransactionCase, Form

from odoo.addons.base.tests.common import SavepointCaseWithUserDemo


@tagged('at_install', '-post_install')  # LEGACY at_install
class TestResPartnerBank(SavepointCaseWithUserDemo):
    """Tests account_number
    """

    def test_sanitized_account_number(self):
        partner_bank_model = self.env['res.partner.bank']
        account_number = " BE-001 2518823 03 "
        vals = partner_bank_model.search([('account_number', '=', account_number)])
        self.assertEqual(0, len(vals))
        partner_bank = partner_bank_model.create({
            'account_number': account_number,
            'partner_id': self.env['res.partner'].create({'name': 'Pepper Test'}).id,
        })
        vals = partner_bank_model.search([('account_number', '=', account_number)])
        self.assertEqual(1, len(vals))
        self.assertEqual(partner_bank, vals[0])
        vals = partner_bank_model.search([('account_number', 'in', [account_number])])
        self.assertEqual(1, len(vals))
        self.assertEqual(partner_bank, vals[0])

        self.assertEqual(partner_bank.account_number, account_number)

        # sanitaze the account_number
        sanitized_account_number = 'BE001251882303'
        self.assertEqual(partner_bank.sanitized_account_number, sanitized_account_number)
        vals = partner_bank_model.search(
            [('account_number', '=', sanitized_account_number)])
        self.assertEqual(1, len(vals))
        self.assertEqual(partner_bank, vals[0])
        vals = partner_bank_model.search(
            [('account_number', 'in', [sanitized_account_number])])
        self.assertEqual(1, len(vals))
        self.assertEqual(partner_bank, vals[0])
        self.assertEqual(partner_bank.sanitized_account_number,
                         sanitized_account_number)

        # search is case insensitive
        vals = partner_bank_model.search(
            [('account_number', '=', sanitized_account_number.lower())])
        self.assertEqual(1, len(vals))
        vals = partner_bank_model.search(
            [('account_number', '=', account_number.lower())])
        self.assertEqual(1, len(vals))

        # updating the sanitized value will also update the account_number
        partner_bank.write({'sanitized_account_number': 'BE001251882303WRONG'})
        self.assertEqual(partner_bank.account_number, partner_bank.sanitized_account_number)


class TestResPartnerBankForm(TransactionCase):
    def test_create_res_partner_bank(self):
        bank_account_form = Form(
            self.env['res.partner.bank'].with_context(default_partner_id=self.env.user.partner_id.id))
        bank_account_form.account_number = '11234'
        bank_account_form.save()
